---
name: Feature request
about: Suggest a Method, Resource, Plot
title: ''
labels: enhancement
assignees: dbdimitrov

---

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the desired feature is. 

**Describe the solution you'd like**
A clear and concise description of what you want to happen. Examples from other methods are welcome.


Contributions to LIANA are also more than welcome!
